Dejitter — Kivy v1.0.1-dev documentation

# Dejitter

Prevent blob jittering.

A problem that is often faced (esp. in optical MT setups) is that of jitterish BLOBs caused by bad camera characteristics. With this module you can get rid of that jitter. You just define a threshold jitter_distance in your config, and all touch movements that move the touch by less than the jitter distance are considered ‘bad’ movements caused by jitter and will be discarded.

class `kivy.input.postproc.dejitter.` `InputPostprocDejitter`

  Bases: `object`

  Get rid of jitterish BLOBs. Example

      [postproc]
      jitter_distance = 0.004
      jitter_ignore_devices = mouse,mactouch

  Configuration : | jitter_distance: float A float in range 0-1. jitter_ignore_devices: string A comma-seperated list of device identifiers that should not be processed by dejitter (because they’re very precise already).